/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the New BSD License (3-clause license).
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the New BSD License (3-clause license)
 * for more details.
 *
 * You should have received a copy of the New BSD License (3-clause license)
 * along with this program/library; If not, see http://directory.fsf.org/wiki/License:BSD_3Clause/
 * for the New BSD License (3-clause license).
 */
package com.ebmwebsourcing.easycommons.stream;

import java.io.ByteArrayInputStream;
import java.io.InputStream;

/**
 * This forker class allow to create on demand one copy of
 * original {@link InputStream} provided. Several copies can be recovered by
 * many calls to its, but take in account that original {@link InputStream}
 * provided will be consumed.
 *
 * @see InputStreamForker#fork()
 *
 * @author aruffie
 */
public final class InputStreamForker {

    private final byte[] bytes;
    
    public InputStreamForker(final InputStream originalInputStream) {
        bytes = StreamHelper.getBytes(originalInputStream);
    }
    
    /**
     * This function allow to recover a new {@link InputStream} which contains one
     * copy of the original {@link InputStream}
     * 
     * @return Return one copy of the original {@link InputStream}
     */
    public final InputStream fork() {
        return new ByteArrayInputStream(bytes);
    }
}
